@@ -7,8 +7,9 @@ use syn::{parse_macro_input, AttributeArgs, ItemFn};
 
 use crate::proc_macro::TokenStream;
 use crate::macros::crud_table_impl::{impl_crud_driver, impl_crud};
+use crate::macros::html_sql_impl::impl_macro_html_sql;
 use crate::macros::sql_impl::impl_macro_sql;
-use crate::macros::py_sql_impl::{impl_macro_py_sql, impl_macro_html_sql};
+use crate::macros::py_sql_impl::{impl_macro_py_sql};
 
 mod macros;
 mod util;
@@ -18,17 +19,17 @@ pub fn hello_macro_derive(input: TokenStream) -> TokenStream {
     let ast = syn::parse(input).unwrap();
     let stream = impl_crud_driver(&ast, "", "", &HashMap::new());
     #[cfg(feature = "debug_mode")]
-    {
-        println!("............gen impl CRUDTable:\n {}", stream);
-        println!("............gen impl CRUDTable end............");
-    }
+        {
+            println!("............gen impl CRUDTable:\n {}", stream);
+            println!("............gen impl CRUDTable end............");
+        }
 
     stream
 }
 
 /// auto create sql macro,this macro use RB.fetch_prepare and RB.exec_prepare
 /// for example:
-///     lazy_static! { pub static ref RB: Rbatis = Rbatis::new(); }
+///     pub static RB:Lazy<Rbatis> = Lazy::new(||Rbatis::new());
 ///     #[sql(RB, "select * from biz_activity where id = ?")]
 ///     async fn select(name: &str) -> BizActivity {}
 ///
@@ -42,17 +43,17 @@ pub fn sql(args: TokenStream, func: TokenStream) -> TokenStream {
     let target_fn: ItemFn = syn::parse(func).unwrap();
     let stream = impl_macro_sql(&target_fn, &args);
     #[cfg(feature = "debug_mode")]
-    {
-        println!("............gen macro sql:\n {}", stream);
-        println!("............gen macro sql end............");
-    }
+        {
+            println!("............gen macro sql:\n {}", stream);
+            println!("............gen macro sql end............");
+        }
 
     stream
 }
 
 /// py sql create macro,this macro use RB.py_fetch and RB.py_exec
 ///
-///  lazy_static! { pub static ref RB: Rbatis = Rbatis::new(); }
+///  pub static RB:Lazy<Rbatis> = Lazy::new(||Rbatis::new());
 ///  #[py_sql(RB,"select * from biz_activity where delete_flag = 0")]
 ///  async fn py_select_page(page_req: &PageRequest, name: &str) -> Page<BizActivity> { todo!() }
 ///  or:
@@ -93,17 +94,17 @@ pub fn py_sql(args: TokenStream, func: TokenStream) -> TokenStream {
     let target_fn: ItemFn = syn::parse(func).unwrap();
     let stream = impl_macro_py_sql(&target_fn, &args);
     #[cfg(feature = "debug_mode")]
-    {
-        println!("............gen macro py_sql :\n {}", stream);
-        println!("............gen macro py_sql end............");
-    }
+        {
+            println!("............gen macro py_sql :\n {}", stream);
+            println!("............gen macro py_sql end............");
+        }
     stream
 }
 
 /// html sql create macro,this macro use RB.py_fetch and RB.py_exec
 /// for example:
 ///
-/// lazy_static! { pub static ref RB: Rbatis = Rbatis::new(); }
+/// pub static RB:Lazy<Rbatis> = Lazy::new(||Rbatis::new());
 /// #[py_sql(RB,"example/example.html")]
 /// pub async fn py_select_rb(name: &str) -> Option<BizActivity> {}
 ///
@@ -140,10 +141,10 @@ pub fn html_sql(args: TokenStream, func: TokenStream) -> TokenStream {
 pub fn crud_table(args: TokenStream, input: TokenStream) -> TokenStream {
     let stream = impl_crud(args, input);
     #[cfg(feature = "debug_mode")]
-    {
-        println!("............gen impl CRUDTable:\n {}", stream);
-        println!("............gen impl CRUDTable end............");
-    }
+        {
+            println!("............gen impl CRUDTable:\n {}", stream);
+            println!("............gen impl CRUDTable end............");
+        }
 
     return stream;
 }
